
# Angular Org Chart

An Angular 13+ library for displaying Organization charts. It's a very lightweigt library with the features currently not available in any other library. It's written in pure typescript and is developed focussing on Angular projects

## Getting Started

For using the chart, you'll need to do the folloing steps:

### Installation
```
npm install angular13-organization-chart --save
```
### Add the dependency in module

Add 'OrgChartModule' in imports

```
import { BrowserModule } from '@angular/platform-browser';
import { NgModule } from '@angular/core';
import { OrgChartModule } from 'angular13-organization-chart';
import { AppComponent } from './app.component';

@NgModule({
  declarations: [
    AppComponent
  ],
  imports: [
    BrowserModule,
	OrgChartModule
  ],
  providers: [],
  bootstrap: [AppComponent]
})
export class AppModule { }

```

### Formatting the data in component

The data requires few parameters for displaying the correct chart:
```
interface OrgData {
	name: string;
    type: string;
    cssClass?: string;
    css?: string;
    onClick?: () => void;
    children: OrgData[];
}
```

Example component

```
import { Component } from '@angular/core';
import { OrgData } from 'angular13-organization-chartt';


@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
export class AppComponent {
    orgData: OrgData= {
        name: 'Felines',
        type: 'The Superior Carnivores',
        onClick: () => alert('Death to dogs'),
        children: [
            {
                name: 'Big Cats',
                type: 'Predators',
                css: 'background-color: red',
                children: [
                    {
                        name: 'Lion',
                        type: '',
                        children: []
                    },
                    {
                        name: 'Tiger',
                        type: '',
                        children: []
                    },
                    {
                        name: 'Cheetah',
                        type: '',
                        children: []
                    }
                ]
            },
            {
                name: 'Small Cats',
                type: 'Domestic',
                children: [
                    {
                        name: 'House Cat',
                        type: '',
                        children: []
                    },
                    {
                        name: 'Street Cat',
                        type: '',
                        children: [
                            {
                                name: 'Dumb Cat',
                                type: '',
                                children: []
                            },
                            {
                                name: 'Good Cat',
                                type: '',
                                children: []
                            }
                        ]
                    }
                ]
            },
            {
                name: 'Fake Cats',
                type: 'Domestic',
                children: []
            }
        ]
      };
}

```

### Using the org chart in HTML template

```
<angular-org-chart id="orgChartId" [data]="orgData"></angular-org-chart>
```
Pleaase note that 'id' is required if you want to change the css. As the style which you'll need to give for the boxes and the lines, you'll be required to add it on the basis of 'id' else the css won't be applied.

## Personalized CSS

Use the 'id' and place these css:
For Lines:
```
#orgChartId .org-chart-entity-border {
	border-left: 1px solid green;
	border-top: 1px solid green;
}
```
For Distance between the levels:
```
#orgChartId .org-chart-entity-connector {
	height: 2em;
}
```
For box styles:
```
#orgChartId .org-chart-entity-box {
	align-items: center;
    border: 1px solid blue;
    background-color: blue;
    border-radius: 3px;
	box-shadow: 0 .5rem 1rem #777!important;
}
```
### Example
![enter image description here](https://raw.githubusercontent.com/MuaazH/org-chart/master/src/assets/example.png)


### Features

* OnClick Callback
* Custom Styles
* Maintained and lightweight code (this is a lie told by the original author)

## Upcoming features

* Add something cool here

## Authors

* **Shrey Kumar Jain** - Original Author
* **MuaazH** - Contributed to the problem.
